@@ -61,10 +61,13 @@ class DataStream(object):
 
     @property
     def entries(self):
+        return self.get_entries()
+
+    def get_entries(self, limit=0):
         return list(self.collection.find(
             {'stream_key': self.key, 'type': DatabaseDocumentTypes.Entry},
             {'_id': 0, 'type': 0, 'stream_key': 0}
-        ))
+        ).limit(limit))
     
     def add_entry(self, data):
         entry = dict()
